import unittest

from gou2tool.util import AddressUtil


class TestDemo(unittest.TestCase):
    def test_simple_uuid(self):
        address = {
            "湖南省邵阳市新邵县酿溪镇临江社区9栋": "湖南省岳阳市湘阴县文星镇江东社区甘妃巷",
            "衡东县城关镇滨江大道423号": "涟滨北路403号",
            "湖北省孝感市汉川市西江乡北河B1-6-2": "湖北省宜昌市宜都市长江大道176号",
            "湖南省邵阳市邵东市两市塘街道文化社区文化路8号门面": "湖南省邵阳市邵东市宋家塘街道四通路10栋1号",
            "湖北省黄冈市武穴市永宁大道锦林商厦106室": "湖北省宜昌市宜都市长江大道176号",
            "湖南省怀化市鹤城区红星街道天星东路盛世华都北区4栋101号": "天星东路盛世华都北区2栋110号",
            "湖南省娄底市双峰县永丰镇艺芳和苑16栋128号": "湖南省娄底市双峰县蔡和森大道东439号",
            "湖南省怀化市溆浦县卢峰镇迎宾西路城北壹号3期商业2栋1单元151": "湖南省怀化市溆浦县迎宾路",
            "湖南省衡阳市衡东县洣水镇商业步行街266号": "湖南省衡阳市衡南县云集华苑商城C栋1一30洋园巷",
            "湖北省武汉市汉阳区汉阳大道654号-8号（门面）-2": "湖北省武汉市青山区和平大道1546号附3号",
            "湖南省常德市汉寿县龙阳街道护城社区辰阳南路芙蓉世纪城4栋811号": "龙阳街道城南社区银水东路248号",
            "交通路141号": "交通路149号",
            "湖南省永州市宁远县舜陵街道九疑中路223号": "湖南省永州市宁远县舜陵街道九疑中路362-364号",
            "衡阳县西渡镇新正街45号2栋201室": "西渡镇新正街45号2栋201室",
            "湖南省永州市宁远县舜陵街道九疑中路75号兴龙第一街A209号": "湖南省永州市宁远县舜陵街道九疑中路362-364号",
            "湖南省邵阳市隆回县花门街道418路2栋1号": "湖南省邵阳市邵东市宋家塘街道四通路10栋1号",
            "浏阳市淳口镇鹤源村淳农大道173号": "浏阳市商贸城大市场7栋21号",
            "湖北省孝感市孝昌县周巷镇教育路16号": "湖北省宜昌市秭归县茅坪镇天问路16号",
            "湖南省长沙市望城区月亮岛街道南山苏迪亚诺H23栋114号门面": "南山苏迪亚诺北门H23栋114门面",
            "湖南省邵阳市邵东市宋家塘街道办事处金泉村-邵东壹号16栋109室": "湖南省邵阳市邵东市宋家塘街道四通路10栋1号",
            "湖南省衡阳市衡南县洪山镇狮塘路": "湖南省衡阳市衡阳县复源路",
            "丹江口市习家店镇习氏小巷": "习家店镇习氏小巷",
            "湖南省株洲市荷塘区新华东路1557号银泰财富广场1栋1604号": "荷塘区新华东路1557号银泰财富广场负一楼202",
            "长沙市开福区浏阳河街道福元西路109号珠江悦界商业中心B1-B5栋6层6065号房": "浏阳河街道福元西路109号珠江星环购物中心L1层1406号",
            "湖南省株洲市芦淞区建宁街道车站路61号中鸿.时尚新天地国际公寓2座813号": "车站路61号中鸿时尚新天地国际公寓2座1812-1814",
            "孝南经济开发区三军社区万达广场1F -JY-BX-009": "孝南经济开发区董湖社区赛达康城16幢0111.0112号",
            "邵阳市邵东市大禾塘街道红土岭社区百兴路134号": "市大禾塘街道红土岭社区兴东路88号",
            "湖南省涟源市蓝田办事处交通路西侧前排3楼  （B）": "蓝田办事处交通路西侧前排建设银行旁二楼",
            "湖南省长沙市雨花区砂子塘街道新建东路35号阳光锦城1栋1317房": "砂子塘街道新建东路35号阳光锦城1009号",
            "湖南省衡阳市衡阳县西渡镇体育花园门面": "湖南省衡阳市衡阳县复源路",
            "湖南省郴州市桂阳县正和镇迎宾路龙翔福邸1栋A3号": "湖南省怀化市溆浦县迎宾路",
            "潜江市园林办事处城南居委会二组106号": "园林办事处城南居委会一组74号",
            "湘潭市高新区双马街道芙蓉路18号综合楼1栋0601001号": "双马街道芙蓉路18号综合楼1栋5号",
            "湖北省黄石市阳新县城东管理区太阳城二期学士楼9栋104号铺": "城东管理区太阳城二期8栋109商铺",
            "沙洋县园林路3-4号": "松竹花园A栋3-4号",
            "湖北省荆州市洪湖市新堤街道宏伟南路宝安商业广场一楼1242号（自主申报）": "新堤街道宏伟南路宝安广场1305号",
            "武汉市东西湖区常青花园13街24村24栋4单元4层2室": "常青花园13区13栋3单元1层1室",
            "湖南省衡阳市耒阳市五里牌街道办事处金星居委会发明家广场c区4幢103号": "五里牌街道金星居委会发明家广场B区北栋2101号",
            "鄂州市南浦路56号南浦国际1-2808": "南浦路56号南浦国际广场",
            "湖南省衡阳市祁东县玉合街道建设北路195号": "湖南省邵阳市邵东市宋家塘街道四通路10栋1号",
            "湖南省长沙市望城区月亮岛街道龙湖湘风原著S17#栋114室": "月亮岛街道龙湖湘风原著小区S5栋113号",
            "湖南省常德市西洞庭管理区龙泉街道祝丰东路027号": "龙泉街道祝丰东路027号",
            "京山县宋河镇映月路18号": "洪山镇滨河别墅118号",
            "十堰市郧阳区柳陂镇商业二街": "柳陂镇商业二街",
            "湖南省衡阳市珠晖区湘江五金大市场6栋12号": "浏阳市商贸城大市场7栋21号",
            "长沙市开福区新河街道湘江北路三段1200号北辰三角洲C2区G层、商业及地下室G层112号商铺": "湘江北路三段1200号北辰三角洲奥城C2区G层商业及地下室1015",
            "湖南省吉首市湘泉步行街B栋2楼19-20号": "湘泉步行街B栋二楼",
            "湖南省永州市祁阳县龙山街道办事处陶铸路452号": "零阳街道东街社区朝王路45号",
            "湖南省衡阳市祁东县玉合街道祁丰大道248号": "湖南省衡阳市祁东县洪桥镇莲花东路320号",
            "湖南省株洲市天元区嵩山路街道天台路80号汇金财智天下1、2、3栋润鲨奥特莱斯一楼1016A号": "嵩山路街道天台路80号汇金财智天下123栋1543",
            "湖南省益阳市安化县东坪镇建设社区梅山路81号": "东坪镇建设社区梅山路59号",
            "湖北省黄冈市黄州区赤壁二路21号碧桂园中央公馆7号楼1层104号商铺": "赤壁二路21号碧桂园中央公馆",
            "邵阳县塘田市镇紫春路96号": "塘田市镇振兴路35号",
            "湖北省荆门市钟祥市胡集镇车站二路118号": "京山市湖北省荆门市新市镇小中路17号",
            "武汉市武昌区杨园街柴林头村融桥城K3-2地块二期12栋/单元1层6号（此证与拆迁补偿无关）": "杨园街柴林村融侨城K3-2地块二期10栋/单元1层5号",
            "湖南省永州市祁阳市长虹街道芹菜甸社区栖霞路97号6楼": "市湖南省长虹街道平安街社区新兴路447号",
            "湖南省衡阳市衡阳县洪市镇洪双北路67号": "湖南省衡阳市祁东县洪桥镇莲花东路320号",
            "湖南省衡阳市衡南县三塘镇衡祁东路": "湖南省衡阳市衡阳县复源路",
            "湖南省湘潭市高新区双马街道芙蓉路26号湘潭万达广场6号楼3单元0103004": "双马街道芙蓉路26号(湘潭万达广场6号楼3单元)",
            "湖南省常德市澧县澧阳街道珍珠居委会澧阳桥621号": "湖南省 常德市 澧县 澧阳街道万宫居委会欢乐城万达广场B区2605号",
            "湖南省衡阳市衡南县云集街道云集大道天成市场3栋2楼": "湖南省衡阳市衡南县云集华苑商城C栋1一30洋园巷",
            "湖南省株洲市醴陵市泉湖路全胜小区36号": "泉湖路全胜小区28号",
            "湖南省益阳市桃江县桃花江镇育英巷141号": "桃花江镇罗溪路11号",
            "荆州区绛帐路恒大名都1号楼101号（自主申报）": "恒大1期门面101号",
            "湖南省郴州市桂东县沤江镇维夏路": "湖南省郴州市嘉禾县珠泉西路",
            "湘潭市雨湖区雨湖路街道建设北路8号白石商业广场1单元110125号": "雨湖路街道建设北路8号白石商业广场1单元",
            "湖南省澧县澧阳街道办事处珍珠居委会澧州路418号": "澧西街道办事处关心居委会澧州路1008号",
            "湖南省衡阳市石鼓区黄沙湾街道华源支路6号雅士林欣城G22栋103室": "黄沙湾街道华源支路雅士林欣城G17栋103",
            "益阳市大通湖区河坝镇五一路294号": "河坝镇五一路媚姿",
            "湖南省郴州市北湖区人民西路2号": "湖南省郴州市嘉禾县珠泉西路",
            "湖南省常德市鼎城区玉霞街道永安社区大湖路353号": "玉霞街道永安社区大湖路785号",
            "天门市岳口镇解放大道113号": "岳口镇解放大道113号",
            "湖南省邵阳市邵东市宋家塘街道新辉社区兴和一路76号二楼": "湖南省邵阳市邵东市宋家塘街道四通路10栋1号",
            "湖南省岳阳市华容县田家湖生态新区杏花村西路15-108号": "田家湖生态新区杏花村西路20-1-2号",
            "湖南省武冈市新东路东升北路以东都梁华府2栋120门面": "新东路以东都粱华府2栋120门面",
            "株洲市荷塘区红旗中路238号东方时代广场8栋910号": "红旗中路东方时代广场8栋204",
            "湖南省衡阳市蒸湘区蒸湘街道蔡伦大道66号融冠乐城项目B9栋202号商铺": "蒸湘街道蔡伦大道66号融冠乐城项目C4栋204-1号",
            "湖北省武汉市武昌区杨园街道才华街12附3号": "湖北省武汉市青山区和平大道1546号附3号",
            "湖南省邵阳市隆回县桃花坪街道紫霞园社区辰河二期D4-508号": "桃花坪街道大井社区工商街158号",
            "长沙市开福区湘江北路三段1200号北辰三角洲奥城D2区商业车库栋G层101房": "新河街道湘江北路三段1200号北辰三角洲奥城D2区商业车库G层027号门面",
            "湖南省岳阳市岳阳县新墙镇新墙河居委会南街40号": "新墙镇中心卫生院南侧180米",
            "湖南省郴州市苏仙区白鹿洞街道香雪桥社区青年大道306号恒大帝景小区5栋1205": "白鹿洞街道香雪桥社区青年大道306号恒大帝景小区14栋103",
            "湖南省郴州市桂阳县鹿峰街道向阳路3号103铺": "湖南省郴州市阳县峰街道向阳路四号1幢",
            "湖南省株洲市芦淞区建设街道新华西路1238号双银大厦2112室": "建设街道新华西路1238号双银大厦2205号",
            "湖北省宜昌市夷陵区小溪塔街道平云二路12号2栋1单元1层102室": "湖北省宜昌市夷陵区小溪塔街道锦江东路1号1-45",
            "常德市武陵区府坪街道府坪巷社区建设路鸿正苑A2栋301": "高山街广场鸿正苑小区a2栋2单元305",
            "湖南省衡阳市衡东县洣水镇洣江大道617号": "洣水镇洣水大道617号",
            "英山县温泉镇北门坳巷20号": "英山县人民医院东南门东120米",
            "桃江县桃花江镇芙蓉路": "桃江县桃花江镇建设路134号",
            "夷陵区小溪塔街办冯家湾社区夷兴大道1-1-210": "小溪塔街办冯家湾社区夷兴大道24号",
            "湖北省武汉市洪山区珞南街道珞喻路1号鹏程国际A2610号": "洪山区珞南街道珞喻路鹏程国际A座2610",
            "建始县高坪镇桑园坝社区二组": "高坪镇桑园坝二组",
            "宜都市陆城名都花园碧水苑1号楼1-105号": "名都路碧水苑西门旁",
            "蕲春县青石镇青石大道600号": "长安大道100号",
            "长沙市天心区金盆岭街道天剑社区南湖路44号永宏佳园1栋103、104上层门面。": "南湖路永宏佳园202号街边门面二楼",
            "汉寿县龙阳街道城东社区银水东路23号": "龙阳街道城南社区银水东路248号",
            "潜江市园林街道办事处紫光路30号": "园林街道办事处湖滨路52号",
            "湖北省荆门市漳河新区象山大道251号时代华庭S2-100号": "漳河新区双喜街道龙山脊社区象山大道247号楚荣华府2幢-102号房",
        }
        # 创建一个列表来存储地址对和相似度
        address_pairs = []

        # 遍历字典并计算相似度
        for key, value in address.items():
            similarity = AddressUtil.calculate_similarity(key, value)
            address_pairs.append((similarity, key, value))

        # 按相似度降序排序
        address_pairs.sort(key=lambda x: x[0], reverse=True)

        # 打印排序后的结果
        for similarity, addr1, addr2 in address_pairs:
            print(f"相似度: {similarity}, 地址1: {addr1}, 地址2: {addr2}")
        self.assertTrue(True)

    def test__uuid(self):
        address_list = [
            "系统地址",
            "湖南省邵阳市新邵县酿溪镇临江社区9栋",
            "衡东县城关镇滨江大道423号",
            "湖北省孝感市汉川市西江乡北河B1-6-2",
            "湖南省邵阳市邵东市两市塘街道文化社区文化路8号门面",
            "湖北省黄冈市武穴市永宁大道锦林商厦106室",
            "湖南省怀化市鹤城区红星街道天星东路盛世华都北区4栋101号",
            "湖南省娄底市双峰县永丰镇艺芳和苑16栋128号",
            "湖南省怀化市溆浦县卢峰镇迎宾西路城北壹号3期商业2栋1单元151",
            "湖南省衡阳市衡东县洣水镇商业步行街266号",
            "湖北省武汉市汉阳区汉阳大道654号-8号（门面）-2",
            "湖南省常德市汉寿县龙阳街道护城社区辰阳南路芙蓉世纪城4栋811号",
            "交通路141号",
            "湖南省永州市宁远县舜陵街道九疑中路223号",
            "衡阳县西渡镇新正街45号2栋201室",
            "湖南省永州市宁远县舜陵街道九疑中路75号兴龙第一街A209号",
            "湖南省邵阳市隆回县花门街道418路2栋1号",
            "浏阳市淳口镇鹤源村淳农大道173号",
            "湖北省孝感市孝昌县周巷镇教育路16号",
            "湖南省长沙市望城区月亮岛街道南山苏迪亚诺H23栋114号门面",
            "湖南省邵阳市邵东市宋家塘街道办事处金泉村-邵东壹号16栋109室",
            "湖南省衡阳市衡南县洪山镇狮塘路",
            "丹江口市习家店镇习氏小巷",
            "湖南省株洲市荷塘区新华东路1557号银泰财富广场1栋1604号",
            "长沙市开福区浏阳河街道福元西路109号珠江悦界商业中心B1-B5栋6层6065号房",
            "湖南省株洲市芦淞区建宁街道车站路61号中鸿.时尚新天地国际公寓2座813号",
            "孝南经济开发区三军社区万达广场1F -JY-BX-009",
            "邵阳市邵东市大禾塘街道红土岭社区百兴路134号",
            "湖南省涟源市蓝田办事处交通路西侧前排3楼  （B）",
            "湖南省长沙市雨花区砂子塘街道新建东路35号阳光锦城1栋1317房",
            "湖南省衡阳市衡阳县西渡镇体育花园门面",
            "湖南省郴州市桂阳县正和镇迎宾路龙翔福邸1栋A3号",
            "潜江市园林办事处城南居委会二组106号",
            "湘潭市高新区双马街道芙蓉路18号综合楼1栋0601001号",
            "湖北省黄石市阳新县城东管理区太阳城二期学士楼9栋104号铺",
            "沙洋县园林路3-4号",
            "湖北省荆州市洪湖市新堤街道宏伟南路宝安商业广场一楼1242号（自主申报）",
            "武汉市东西湖区常青花园13街24村24栋4单元4层2室",
            "湖南省衡阳市耒阳市五里牌街道办事处金星居委会发明家广场c区4幢103号",
            "鄂州市南浦路56号南浦国际1-2808",
            "湖南省衡阳市祁东县玉合街道建设北路195号",
            "湖南省长沙市望城区月亮岛街道龙湖湘风原著S17#栋114室",
            "湖南省常德市西洞庭管理区龙泉街道祝丰东路027号",
            "京山县宋河镇映月路18号",
            "十堰市郧阳区柳陂镇商业二街",
            "湖南省衡阳市珠晖区湘江五金大市场6栋12号",
            "长沙市开福区新河街道湘江北路三段1200号北辰三角洲C2区G层、商业及地下室G层112号商铺",
            "湖南省吉首市湘泉步行街B栋2楼19-20号",
            "湖南省永州市祁阳县龙山街道办事处陶铸路452号",
            "湖南省衡阳市祁东县玉合街道祁丰大道248号",
            "湖南省株洲市天元区嵩山路街道天台路80号汇金财智天下1、2、3栋润鲨奥特莱斯一楼1016A号",
            "湖南省益阳市安化县东坪镇建设社区梅山路81号",
            "湖北省黄冈市黄州区赤壁二路21号碧桂园中央公馆7号楼1层104号商铺",
            "邵阳县塘田市镇紫春路96号",
            "湖北省荆门市钟祥市胡集镇车站二路118号",
            "武汉市武昌区杨园街柴林头村融桥城K3-2地块二期12栋/单元1层6号（此证与拆迁补偿无关）",
            "湖南省永州市祁阳市长虹街道芹菜甸社区栖霞路97号6楼",
            "湖南省衡阳市衡阳县洪市镇洪双北路67号",
            "湖南省衡阳市衡南县三塘镇衡祁东路",
            "湖南省湘潭市高新区双马街道芙蓉路26号湘潭万达广场6号楼3单元0103004",
            "湖南省常德市澧县澧阳街道珍珠居委会澧阳桥621号",
            "湖南省衡阳市衡南县云集街道云集大道天成市场3栋2楼",
            "湖南省株洲市醴陵市泉湖路全胜小区36号",
            "湖南省益阳市桃江县桃花江镇育英巷141号",
            "荆州区绛帐路恒大名都1号楼101号（自主申报）",
            "湖南省郴州市桂东县沤江镇维夏路",
            "湘潭市雨湖区雨湖路街道建设北路8号白石商业广场1单元110125号",
            "湖南省澧县澧阳街道办事处珍珠居委会澧州路418号",
            "湖南省衡阳市石鼓区黄沙湾街道华源支路6号雅士林欣城G22栋103室",
            "益阳市大通湖区河坝镇五一路294号",
            "湖南省郴州市北湖区人民西路2号",
            "湖南省常德市鼎城区玉霞街道永安社区大湖路353号",
            "天门市岳口镇解放大道113号",
            "湖南省邵阳市邵东市宋家塘街道新辉社区兴和一路76号二楼",
            "湖南省岳阳市华容县田家湖生态新区杏花村西路15-108号",
            "湖南省武冈市新东路东升北路以东都梁华府2栋120门面",
            "株洲市荷塘区红旗中路238号东方时代广场8栋910号",
            "湖南省衡阳市蒸湘区蒸湘街道蔡伦大道66号融冠乐城项目B9栋202号商铺",
            "湖北省武汉市武昌区杨园街道才华街12附3号",
            "湖南省邵阳市隆回县桃花坪街道紫霞园社区辰河二期D4-508号",
            "长沙市开福区湘江北路三段1200号北辰三角洲奥城D2区商业车库栋G层101房",
            "湖南省岳阳市岳阳县新墙镇新墙河居委会南街40号",
            "湖南省郴州市苏仙区白鹿洞街道香雪桥社区青年大道306号恒大帝景小区5栋1205",
            "湖南省郴州市桂阳县鹿峰街道向阳路3号103铺",
            "湖南省株洲市芦淞区建设街道新华西路1238号双银大厦2112室",
            "湖北省宜昌市夷陵区小溪塔街道平云二路12号2栋1单元1层102室",
            "常德市武陵区府坪街道府坪巷社区建设路鸿正苑A2栋301",
            "湖南省衡阳市衡东县洣水镇洣江大道617号",
            "英山县温泉镇北门坳巷20号",
            "桃江县桃花江镇芙蓉路",
            "夷陵区小溪塔街办冯家湾社区夷兴大道1-1-210",
            "湖北省武汉市洪山区珞南街道珞喻路1号鹏程国际A2610号",
            "建始县高坪镇桑园坝社区二组",
            "宜都市陆城名都花园碧水苑1号楼1-105号",
            "蕲春县青石镇青石大道600号",
            "长沙市天心区金盆岭街道天剑社区南湖路44号永宏佳园1栋103、104上层门面。",
            "汉寿县龙阳街道城东社区银水东路23号",
            "潜江市园林街道办事处紫光路30号",
            "湖北省荆门市漳河新区象山大道251号时代华庭S2-100号",
            "红安县觅儿寺镇新型产业园（红万家购物广场内）",
            "新宁县金石镇大兴路272号",
            "湖南省衡阳市石鼓区潇湘街道中山北路121号",
            "湖南省郴州市宜章县玉溪镇普化寺社区环城西路18-15号",
            "五峰土家族自治县渔洋关镇茶城",
            "湖南省郴州市资兴市东江街道秀山路37-1号",
            "邵东市宋家塘景秀路662号",
            "湖南省常德市武陵区永安街道牯牛岗社区时光印象小区103号",
            "湖南省吉首市乾州办事处世纪广场商业城B栋1122室",
            "湖南省永州市道县濂溪街道万和世纪城S8栋109号",
            "湖南省湘西土家族苗族自治州永顺县灵溪镇南山社区福石城文化公园F栋3048室",
            "长沙县湘龙街道湘龙路42号保利香槟国际A9栋109号",
            "房县城关镇县门街98号",
            "浏阳市文家市镇人民路160号",
            "湖南省邵阳市邵东市宋家塘街道广场社区荷花路457号二楼",
            "湖南省娄底市新化县上渡街道白沙社区江湾国际4栋164号",
            "湖南省衡阳市衡南县云集镇雅园南路16-17号",
            "湖北省黄石市阳新县兴国镇胜利街162号",
            "湖北省武汉市武汉经济技术开发区沌阳街后官湖大道22号附4",
            "岳阳市屈原管理区营田镇兴盛北街",
            "湖北省孝感市应城市城中街道育才路22号金穗公寓B栋门店",
            "湖南省衡阳市祁东县玉合街道莲花西路836号",
            "新宁县金石镇长征西路29号",
            "湖南省郴州市安仁县安平镇文化路4栋14-118B",
            "湖南省衡阳市祁东县归阳镇振兴西路",
            "鄂州市凤凰路洋澜国际康城18号楼4号商铺",
            "长沙县湘龙街道湘润社区龙塘小区A13栋1楼010号",
            "湖北省孝感市孝南区肖港镇肖祠路115号",
            "湖南省株洲市芦淞区贺家土街道北侧广汇商业广场二楼06号",
            "湖南省澧县澧阳街道办事处新河居委会桃花滩路金芙蓉小区一栋205号",
            "湖南省郴州市北湖区郴江街道民权路41号五岭明珠北商业栋212号",
            "湖南省衡阳市常宁市泉峰街道办事处青阳南路111号门面",
            "阳新县白沙镇天福小区5号楼104门面",
            "应城市解放街220号",
            "长沙市天心区书院南路644号4幢-101房。",
            "益阳高新区朝阳街道大明社区文苑瑞景6栋103号",
            "麻城市中馆驿镇中和街",
            "慈利县零阳街道零阳中路胜汉步行街A栋124-126号",
            "湖南省永州市东安县白牙市镇东山路步行街146号",
            "湖南省邵阳市邵东县大禾塘红昭路121号",
            "英山县温泉镇莲花路60号",
            "湖南省邵阳市双清区石桥街道邵阳大道与建设南路交汇处柏林国际3-2#楼0001006",
            "湖南省株洲市芦淞区人民中路上城国际106号",
            "湖南省长沙市开福区新河街道湘江北路三段1200号北辰三角洲奥城D2区商业车库G层101号房",
            "湖南省衡阳市南岳区南岳镇岳东路25号",
            "湖北省武汉市江汉区解放大道358号武汉广场公寓B座32层8室",
            "湖南省永州市零陵区芝城花园3栋11号",
            "湖南省常德市桃源县浔阳街道二里岗社区理鸣路书香苑6栋108.109号门面",
            "湖南省邵阳市邵东市两市塘街道胜利社区胜利街107号门面",
            "湖南省澧县澧西街道办事处大西门居委会运达城小区14栋2302号",
            "湖南省娄底市娄星区长青西街",
            "醴陵市中央商业广场A栋0501",
            "炎陵县霞阳镇解放路延伸段（天华小区一楼）。",
            "潜江市园林街道办事处江汉路27号",
            "湖北省荆门市钟祥市皇庄街道王府大道王府花园临街门面3栋110房"
        ]
        for item in address_list:
            print(AddressUtil.format(item))
        self.assertTrue(True)


if __name__ == '__main__':
    unittest.main()
